@@ -31,12 +31,6 @@ ICMP::ICMP(const char* host)
                 
 }
 
-ICMP::ICMP(u_int32_t dst) : IP(dst, IPPROTO_ICMP)
-{
-        memset(&icmphdr, 0, sizeof(icmphdr));
-}
-		
-
 ICMP::~ICMP()
 {
 }
@@ -60,19 +54,6 @@ ICMP &ICMP::operator=(const ICMP &rhs)
 	return *this;
 }
 
-
-ICMP &ICMP::operator=(const IP &rhs)
-{
-    iphdr iph;
-	if (this == &rhs)
-		return *this;
-	IP::operator=(rhs);
-    iph = IP::get_iphdr();
-	icmphdr = *(struct icmphdr *)((char *)&iph + IP::get_hlen() * 4);
-	return *this;
-}
-
-
 /* Set the type-field in the actuall ICMP-packet.
  */
 int ICMP::set_type(u_int8_t t)
@@ -155,15 +136,6 @@ u_int16_t ICMP::get_seq()
    	return icmphdr.un.echo.sequence;
 }
 
-/* get orig datagram from icmp unreachable
- *
- */
-iphdr ICMP::get_orig() {
-    iphdr iph = *(iphdr *)((char *)(&icmphdr + 1));
-    return iph;
-}
-
-
 /* send an ICMP-packet containing 'payload' which
  *  is 'paylen' bytes long
  */
