@@ -31,9 +31,6 @@ public:
 	/*! Expects host.
 	 */
       	ICMP(const char*);
-	/*! Expects destination i network byte order
-	 */
-		ICMP(u_int32_t);
 
 	virtual ~ICMP();
 
@@ -43,9 +40,6 @@ public:
 	/*! Assign-operator */
 	ICMP &operator=(const ICMP &);
 
-	/*! Assign-operator */
-	ICMP &operator=(const IP &);
-
 	/*! send an ICMP-packet containing 'payload' which
 	 *  is 'paylen' bytes long
 	 */
@@ -112,8 +106,6 @@ public:
         /*! Get the sequence-number of actuall ICMP-packet
 	 */
         u_int16_t get_seq();
-
-        iphdr get_orig();
         
         u_int32_t get_gateway();
         
