@@ -39,53 +39,50 @@ public:
          */
         IP(u_int32_t, u_int8_t);	
 
-    /*! expects ipheader */
-    IP(iphdr &iphh);    
-
 	/*! Destructor
 	 */
         virtual ~IP();
 
 	/*! Returns headerlen/4.
          */
-      	u_int8_t get_hlen() const;
+      	u_int8_t get_hlen();
 
 	/*! returns IP-version. Should give 4 always.
          */
-        u_int8_t get_vers() const;
+        u_int8_t get_vers();
 
 	/*! Get Type Of Service.
          */
-        u_int8_t get_tos() const;
+        u_int8_t get_tos();
 
 	/*! Get total length of packet, including any data.
          *  Return len in host-order.
          */
-        u_int16_t get_totlen() const;
+        u_int16_t get_totlen();
 
 	/*! Get id-field.
          */
-        u_int16_t get_id() const;
+        u_int16_t get_id();
 
 	/*! Get fragmentation offset.
 	 */
-        u_int16_t get_fragoff() const;
+        u_int16_t get_fragoff();
 
 	/*!*/
-        u_int16_t get_fflags() const;
+        u_int16_t get_fflags();
 
 	/*! Get Time To Live field (TTL)
 	 * \example trace.cc
          */
-        u_int8_t get_ttl() const;
+        u_int8_t get_ttl();
 
 	/*! Get protocol, TCP or such.
          */
-        u_int8_t get_proto() const;
+        u_int8_t get_proto();
 
 	/*! Get IP-header checksum
          */
-        u_int16_t get_sum() const;
+        u_int16_t get_sum();
 
     /*! Return the IP header checksum(meder)
      */
@@ -93,11 +90,11 @@ public:
 
 	/*! Get source-adress of packet, in network order.
          */
-        u_int32_t get_src() const;
+        u_int32_t get_src();
 
 	/*! Ditto, destination-adress.
  	 */
-        u_int32_t get_dst() const;
+        u_int32_t get_dst();
 
 	/*! assig-operator
  	 */
@@ -174,8 +171,7 @@ public:
 	/*! Return complete IP header.
 	 * usefull for special ICMP packets
 	 */
-	iphdr get_iphdr() const;
-	int set_iphdr(struct iphdr);
+	iphdr get_iphdr();
 
 	/*! Send a Packet.
          */
@@ -190,23 +186,6 @@ public:
 
 	/*!*/
 	virtual int init_device(char *, int, size_t);
-
-	friend bool operator== (const IP& left, const IP& right) {
-		/*
-		 * XXX: leave IP options comparison for later
-		 */
-		return (left.get_src() == right.get_src() &&
-				left.get_dst() == right.get_dst()&&
-				left.get_hlen() == right.get_hlen() &&
-				left.get_tos() == right.get_tos() &&
-				left.get_totlen() == right.get_totlen() &&
-				left.get_fragoff() == right.get_fragoff() &&
-				left.get_ttl() == right.get_ttl() &&
-				left.get_proto() == right.get_proto() &&
-				((left.get_id() != 0 && right.get_id() != 0) || (left.get_id() == 0 && right.get_id() == 0))
-				);
-	}
-	virtual std::string to_string(void);
 };
 
 
