@@ -25,15 +25,9 @@ class TCP : public IP {
 private:
       	struct tcphdr tcph;
       	char tcpOptions[40];
-		unsigned int opt_offset;
       	struct pseudohdr pseudo;
-		/*
-		 * "cached" data from parsed TCP options
-		 */
-		mutable unsigned int timestamps[2], wscale;
 public:
       	
-	TCP(void);
 	/*! Expects hostname or IP-adress.
          */
 	TCP(const char*);
@@ -52,24 +46,24 @@ public:
 
        /*! Get sourceport of packet, in host-order.
        	*/
-      	u_int16_t get_srcport() const;
+      	u_int16_t get_srcport();
 
        /*! Get destination-port in host-order
        	*/
-      	u_int16_t get_dstport() const;
+      	u_int16_t get_dstport();
 
       	/*! Get sequencenumber of packet.
        	 */
-      	u_int32_t  get_seq() const;
+      	u_int32_t  get_seq();
 
       	/*! Get acknowlegde-number of packet.
        	 */
-      	u_int32_t  get_ack() const;
+      	u_int32_t  get_ack();
 
       	/*! Get TCP-data offset, sometimes called TCP-header-length.
        	*  Should be 20 in most cases.
        	*/
-      	u_int8_t get_off() const;
+      	u_int8_t get_off();
 
        /*! Get TCP-flags. Can be either of
        	*  TH_SYN
@@ -81,19 +75,17 @@ public:
        	* or any combination of these (althought common combinations are SYN|ACK or
        	* similar)
        	*/
-	u_int8_t get_flags() const;      
+	u_int8_t get_flags();      
       
 	/*!*/
-	u_int16_t get_win() const;
+        u_int16_t get_win();
       
 	/*!*/
-	u_int16_t get_tcpsum() const;
+        u_int16_t get_tcpsum();
       	
 	/*!
          */
-	u_int16_t get_urg() const;
-
-	u_int32_t get_wscale() const;
+	u_int16_t get_urg();
       
 	/*! Set source-port 
          */
@@ -132,8 +124,7 @@ public:
 	/*! Return complete TCP header.
 	 *  Usefull for some kinds of ICMP messages
 	 */
-	tcphdr get_tcphdr() const;
-	int set_tcphdr(struct tcphdr);
+	tcphdr get_tcphdr();
 
 	/* The following functions are already defined in IP {}.
 	 * We need them too for TCP {}, and TCP{} calls IP::function() then.
@@ -167,32 +158,6 @@ public:
 	/*! Fill buffer with 20 bytes, return the length of option-field.
 	 */
 	int get_tcpopt(char *);
-	int set_tcpopt(char *, unsigned int);
-
-	friend bool operator== (const TCP& left, const TCP& right) {
-		char left_options[40], right_options[40];
-		bool options_matched=false;
-		memset(left_options, 0, sizeof(left_options));
-		memset(right_options, 0, sizeof(right_options));
-
-		/* remove const'ness for a second */
-		left.get_parsed_tcpopt(left_options, sizeof(left_options));
-		right.get_parsed_tcpopt(right_options, sizeof(right_options));
-
-		if( (memcmp(left_options, right_options, sizeof(left_options))) == 0) {
-			options_matched = true;
-		}
-		return (left.get_flags() == right.get_flags() &&
-				left.get_win() == right.get_win() &&
-				left.get_off() == right.get_off()&&
-				left.get_urg() == right.get_urg() &&
-				options_matched && operator==((IP)left, (IP)right));
-
-	}
-	int get_parsed_tcpopt(char *, unsigned int) const;
-	unsigned int get_tcpopt_tsv(void) { return timestamps[0]; }
-	unsigned int get_tcpopt_tse(void) { return timestamps[1]; }
-	std::string to_string(void);
 };
 
 
