@@ -1,5 +1,5 @@
 
-/* $Id: os_matrix.h,v 1.6 2005/06/26 11:29:50 mederchik Exp $ */
+/* $Id: os_matrix.h,v 1.2 2002/10/21 03:59:42 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -9,6 +9,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,12 +25,10 @@
 #define OS_MATRIX_H
 
 #include "xprobe.h"
-/*
 #include <string>
 #include <map>
 #include <vector>
 #include <algorithm>
-*/
 
 using namespace std;
 
@@ -62,14 +61,12 @@ class OS_Vector {
         int os_id;
         /* we may need this later: map<int, int> mod_score; */
         int total;
-		int numofkwds;
 
     public:
         OS_Vector(int);
         void add_result(int, int);
         int get_total(void) { return total; }
         int get_os_id(void) { return os_id; }
-		int get_number_of_keywords(void) { return numofkwds; }
         friend bool os_vector_compare(const OS_Vector &, const OS_Vector &);
 };
 
@@ -83,14 +80,14 @@ class OS_Matrix {
     public:
         OS_Matrix(int);
         virtual ~OS_Matrix(void);
-        void add_result(int, int, int, int times = 1);
+        void add_result(int, int, int);
         /* returns top num scored OS id */
         int get_top(int);
         /* returns given os_id score */
         int get_score(int);
         /* returns maximum possible score --> max score by number of
          * tests */
-        int get_max_score(int);
+        int get_max_score(void);
         /* returns given os_id score in percent */
         int get_prcnt_score(int);
 };
