@@ -1,4 +1,4 @@
-/* $Id: xplib.h,v 1.7 2005/01/12 07:04:58 mederchik Exp $ */
+/* $Id: xplib.h,v 1.4 2002/11/24 11:37:35 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,7 +34,5 @@
 #include "xp_get_random_data.h"
 #include "xp_get_ping_payload.h"
 #include "xp_get_src_addr.h"
-#include "xp_sha1.h"
-#include "xp_lib.h"
 
 #endif /* XPLIB_H */
