@@ -1,4 +1,4 @@
-/* $Id: icmp_ping.cc,v 1.7 2004/10/12 11:30:04 mederchik Exp $ */
+/* $Id: icmp_ping.cc,v 1.3 2002/11/24 11:42:58 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,21 +31,19 @@
 #include "xprobe_module.h"
 #include "xprobe_module_hdlr.h"
 #include "interface.h"
-#include "cmd_opts.h"
 #include "target.h"
 #include "icmp_ping.h"
 
+#define TIMEOUT 2
 extern Interface *ui;
-extern Cmd_Opts *copts;
 
 /* initialization function */
 
-int icmp_ping_mod_init(Xprobe_Module_Hdlr *pt, char *nm) {
+int icmp_ping_mod_init(Xprobe_Module_Hdlr *pt) {
 
     ICMP_Ping_Mod *module = new ICMP_Ping_Mod;
 
     xprobe_mdebug(XPROBE_DEBUG_MODULES, "Initializing the ICMP PING module\n");
-    module->set_name(nm);
     pt->register_module(module);
 
 return OK;
@@ -87,25 +86,25 @@ int ICMP_Ping_Mod::parse_keyword(int os_id, const char *kwd, const char *val)  {
 int ICMP_Ping_Mod::do_icmp_ping(Target *tg) {
 
     char buf[1024];
-    Xprobe::Timeval tv;
+    struct timeval tv;
     int ret;
     int done;
     unsigned short int icmpp_id;
-    struct in_addr local, remote;
-    Xprobe::Timeval t1, t2, tt; // to calc rtt
+    struct in_addr local;
 
 /* our lamyer randomizer ;-p */
     srand(time(NULL));
     icmpp_id = rand();
     local = tg->get_interface_addr();
-	remote = tg->get_addr();
 
-    ICMP icmpp(remote.s_addr);
-    ICMP sn(local.s_addr);
+    ICMP icmpp(inet_ntoa(tg->get_addr()));
+    ICMP sn(inet_ntoa(local));
     sn.init_device(tg->get_interface(), 0, 1500);
-	/* sn.setfilter("icmp[0] = 0");*/
-    tv = copts->get_timeout();
-    icmpp.set_src(local.s_addr);
+
+    tv.tv_sec = TIMEOUT;
+    tv.tv_usec = 0;
+
+    icmpp.set_src(inet_ntoa(tg->get_interface_addr()));
     icmpp.set_icmpId(icmpp_id);
     icmpp.set_type(ICMP_ECHO);
     fflush(stderr);
@@ -113,24 +112,17 @@ int ICMP_Ping_Mod::do_icmp_ping(Target *tg) {
     
     icmpp.timeout(tv);
     sn.timeout(tv);
-    t1 = Xprobe::Timeval::gettimeofday();
 	ret = icmpp.send_ping_payload();
     done = 0;
     while (!done) {
         ret = sn.sniffpack(buf, sizeof(buf));
         /* packet response */
-        if (! sn.timeout() && sn.get_src() == remote.s_addr && 
-			sn.get_type() == ICMP_ECHOREPLY && sn.get_icmpId() == icmpp_id) done = 1;
-        if (sn.timeout()) done = 1; /* timeout */    
+        if (ret > 0 && sn.get_type() ==  ICMP_ECHOREPLY
+            && sn.get_icmpId() == icmpp_id) done = 1;
+        if (ret < 1) done = 1; /* timeout */    
     }
-    t2 = Xprobe::Timeval::gettimeofday();
     
-    if (! sn.timeout()) {
-	    tt = t2 - t1;
-        if (tg->get_rtt() < tt) 
-            tg->set_rtt(tt);
-	//if ((double)tg->get_rtt() <= 0.0)
-	//	tg->set_rtt(1.0);
+    if (ret > 0) {
         return 1;
     }
     return 0;
