@@ -1,4 +1,4 @@
-/* $Id: icmp_ping.h,v 1.3 2003/08/05 03:35:11 mederchik Exp $ */
+/* $Id: icmp_ping.h,v 1.1 2002/08/08 11:41:42 fygrave Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,7 +31,7 @@ class ICMP_Ping_Mod: public Xprobe_Module {
     private:
         int do_icmp_ping(Target *);
     public:
-        ICMP_Ping_Mod(void) : Xprobe_Module(XPROBE_MODULE_ALIVETEST, "ping:icmp_ping", "ICMP echo discovery module") { return; }
+        ICMP_Ping_Mod(void) : Xprobe_Module(XPROBE_MODULE_ALIVETEST, "ICMP echo (ping)") { return; }
         ~ICMP_Ping_Mod(void) { return; }
         int init(void);
         int parse_keyword(int, const char *, const char *);
