@@ -1,4 +1,4 @@
-/* $Id: tcp_ping.h,v 1.3 2003/08/05 03:35:11 mederchik Exp $ */
+/* $Id: tcp_ping.h,v 1.1 2002/08/08 11:41:42 fygrave Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,22 +20,22 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#ifndef TCP_PING_H
-#define TCP_PING_H
+#ifndef ICMP_PING_H
+#define ICMP_PING_H
 
 #include "xprobe.h"
 #include "xprobe_module.h"
 
 
-class TCP_Ping_Mod: public Xprobe_Module {
+class ICMP_Ping_Mod: public Xprobe_Module {
+    private:
     public:
-        TCP_Ping_Mod(void) : Xprobe_Module(XPROBE_MODULE_ALIVETEST, "ping:tcp_ping","TCP-based ping discovery module") { return; }
-        ~TCP_Ping_Mod(void) { return; }
+        ICMP_Ping_Mod(void) : Xprobe_Module(XPROBE_MODULE_ALIVETEST, "ICMP ECHO") { return; }
+        ~ICMP_Ping_Mod(void) { return; }
         int init(void);
         int parse_keyword(int, const char *, const char *);
-        int exec(Target *, OS_Matrix *);
+        int exec(OS_Matrix *, struct in_addr);
         int fini(void);
-    private:
 };
 
-#endif /* TCP_PING_H */
+#endif /* ICMP_PING_H */
