@@ -1,4 +1,4 @@
-/* $Id: icmp_addrmask.cc,v 1.14 2005/06/26 11:26:12 mederchik Exp $ */
+/* $Id: icmp_addrmask.cc,v 1.6 2003/04/04 04:01:56 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,15 +34,15 @@
 #include "target.h"
 #include "icmp_addrmask.h"
 
+#define TIMEOUT 5
 extern Interface *ui;
 
 /* initialization function */
 
-int icmp_addrmask_mod_init(Xprobe_Module_Hdlr *pt, char *nm) {
+int icmp_addrmask_mod_init(Xprobe_Module_Hdlr *pt) {
 
     ICMP_Addrmask_Mod *module = new ICMP_Addrmask_Mod;
 
-    module->set_name(nm);
     xprobe_mdebug(XPROBE_DEBUG_MODULES, "Initializing the ICMP Addrmask module\n");
     pt->register_module(module);
     pt->add_keyword(module->get_id(),"icmp_addrmask_reply");
@@ -52,15 +53,15 @@ return OK;
 }
 
 
-ICMP_Addrmask_Mod::ICMP_Addrmask_Mod(void): Xprobe_Module(XPROBE_MODULE_OSTEST, "fingerprint:icmp_amask","ICMP Address mask request fingerprinting module") { 
+ICMP_Addrmask_Mod::ICMP_Addrmask_Mod(void): Xprobe_Module(XPROBE_MODULE_OSTEST, "ICMP Address") { 
 
 	ICMP_Addrmask_Reply_Check *repchk = new ICMP_Addrmask_Reply_Check;
 	ICMP_Addrmask_Ip_Id_Check *ipidchk = new ICMP_Addrmask_Ip_Id_Check;
 	ICMP_Addrmask_Ttl_Check	*ttlchk = new ICMP_Addrmask_Ttl_Check;
 
-	kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_addrmask_reply", repchk));
-	kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_addrmask_reply_ttl", ttlchk));
-	kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_addrmask_reply_ip_id", ipidchk));
+	kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_addrmask_reply", repchk));
+	kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_addrmask_reply_ttl", ttlchk));
+	kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_addrmask_reply_ip_id", ipidchk));
 }
 
 ICMP_Addrmask_Mod::~ICMP_Addrmask_Mod(void) {
@@ -94,9 +95,10 @@ int ICMP_Addrmask_Mod::fini(void) {
 
 int ICMP_Addrmask_Mod::parse_keyword(int os_id, const char *kwd, const char *val) {
 
-	if ((s_i = kwd_chk.find(kwd)) != kwd_chk.end()) {
+	for (s_i=kwd_chk.begin(); s_i != kwd_chk.end(); s_i++)
+		if (s_i->first == kwd)
 			return s_i->second->parse_param(os_id, val);
-	}
+
 	ui->msg ("No keywords matched(%s=%s)!", kwd, val);
 	return FAIL;
 }
@@ -110,19 +112,19 @@ int ICMP_Addrmask_Mod::do_icmp_query(Target *tg) {
     int ret;
     int done;
     unsigned short int icmpp_id;
-    struct in_addr local, remote;
+    struct in_addr local;
 
 /* our lamyer randomizer ;-p */
     srand(time(NULL));
     icmpp_id = rand();
     local = tg->get_interface_addr();
-	remote = tg->get_addr();
 
-    ICMP icmpp(inet_ntoa(remote));
+    ICMP icmpp(inet_ntoa(tg->get_addr()));
     ICMP sn(inet_ntoa(local));
     sn.init_device(tg->get_interface(), 0, 1500);
- 
-    tv = tg->get_rtt();
+
+    tv.tv_sec = TIMEOUT;
+    tv.tv_usec = 0;
 
     icmpp.set_src(inet_ntoa(tg->get_interface_addr()));
     icmpp.set_icmpId(icmpp_id);
@@ -140,74 +142,20 @@ int ICMP_Addrmask_Mod::do_icmp_query(Target *tg) {
         ret = sn.sniffpack(buf, sizeof(buf));
         xprobe_debug(XPROBE_DEBUG_MODULES, "Received %i bytes\n", ret);
         /* packet response */
-//        if (ret > 0 && sn.get_src() != local.s_addr 
-        if (!sn.timeout() && sn.get_src() == remote.s_addr 
-            && sn.get_type() == ICMP_ADDRESSREPLY && sn.get_icmpId() == icmpp_id) {
-			done = 1;
-			xprobe_debug(XPROBE_DEBUG_MODULES, "[%s] Received reply.\n", get_name());
-		}
+        if (ret > 0 && sn.get_src() != local.s_addr 
+            && sn.get_icmpId() == icmpp_id) done = 1;
 //        if (ret < 1) done = 1; /* timeout */    
-		if (sn.timeout()) {
-			done = 1; 
-			xprobe_debug(XPROBE_DEBUG_MODULES, "[%s] Timed out, no reply received.\n", get_name());
-		}
+		if (sn.timeout()) done = 1; 
     }
     
     xprobe_mdebug(XPROBE_DEBUG_MODULES, "Got good ICMP response\n");
 	for (s_i = kwd_chk.begin(); s_i != kwd_chk.end(); s_i++)
 		s_i->second->check_param(&sn, &icmpp, current_os);
 
-	if (tg->generate_sig())
-		generate_signature(tg, &sn, &icmpp);
     return OK;
 
 }
 
-void ICMP_Addrmask_Mod::generate_signature(Target *tg, ICMP *pack, ICMP *orig) {
-	string keyword, value;
-	unsigned int ttl;
-	/*
-#       icmp_addrmask_reply = [ y, n]
-#       icmp_addrmask_reply_ttl = [>< decimal num] 
-#       icmp_addrmask_reply_ip_id = [0, !0, SENT]
-	*/
-	if (!pack->timeout()) {
-		keyword = "icmp_addrmask_reply";
-		value = "y";
-		tg->signature(keyword, value);
-		keyword="icmp_addrmask_reply_ttl";
-		ttl = pack->get_ttl() + tg->get_distance();
-		/* following checkpoint values are used for ICMP:
-		 * 32, 64, 128, 255
-		 */
-		value = "<";
-		if (ttl <= 32)
-			value.append("32");
-		else if (ttl <= 60)
-			value.append("60");
-		else if (ttl <= 64)
-			value.append("64");
-		else if (ttl <= 128)
-			value.append("128");
-		else if (ttl <= 255)
-			value.append("255");
-		tg->signature(keyword, value);
-
-		keyword = "icmp_addrmask_reply_ip_id";
-		if (pack->get_id() == 0)
-			value = "0";
-		else if (pack->get_id() == orig->get_id())
-			value = "SENT";
-		else
-			value = "!0";
-		tg->signature(keyword, value);
-	} else {
-		tg->signature("icmp_addrmask_reply", "n");
-		tg->signature("icmp_addrmask_reply_ttl", "<255");
-		tg->signature("icmp_addrmask_reply_ip_id", "!0");
-	}
-}
-
 int ICMP_Addrmask_Reply_Check::check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os) {
 	int gotp=ip_pkt->timeout() ? 0 : 1;
 
