@@ -1,4 +1,4 @@
-/* $Id: icmp_addrmask.h,v 1.8 2004/06/09 12:08:25 mederchik Exp $ */
+/* $Id: icmp_addrmask.h,v 1.4 2003/04/04 04:01:59 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,10 +35,10 @@ typedef struct ttl_val {
 class ICMP_Addrmask_Mod: public Xprobe_Module {
     private:
         OS_Matrix *current_os;
-		map <string, Xprobe_Module_Param_ICMP *> kwd_chk;
-		map <string, Xprobe_Module_Param_ICMP *>::iterator s_i;
+		map <string, Xprobe_Module_Param *> kwd_chk;
+		map <string, Xprobe_Module_Param *>::iterator s_i;
+
         int do_icmp_query(Target *);
-		void generate_signature(Target *, ICMP *, ICMP *);
     public:
         ICMP_Addrmask_Mod(void);
         ~ICMP_Addrmask_Mod(void);
@@ -47,24 +48,24 @@ class ICMP_Addrmask_Mod: public Xprobe_Module {
         int fini(void);
 };
 
-class ICMP_Addrmask_Ip_Id_Check:public Xprobe_Module_Param_ICMP {
+class ICMP_Addrmask_Ip_Id_Check:public Xprobe_Module_Param {
 	public:
-		ICMP_Addrmask_Ip_Id_Check(void):Xprobe_Module_Param_ICMP(XPROBE_MODULE_PARAM_ZNZORIG){ return; }
-		//~ICMP_Addrmask_Ip_Id_Check(void) { return; };
+		ICMP_Addrmask_Ip_Id_Check(void):Xprobe_Module_Param(XPROBE_MODULE_PARAM_ZNZORIG){ return; }
+		~ICMP_Addrmask_Ip_Id_Check(void) { return; };
 		int check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os);
 };
 
-class ICMP_Addrmask_Ttl_Check:public Xprobe_Module_Param_ICMP {
+class ICMP_Addrmask_Ttl_Check:public Xprobe_Module_Param {
 	public:
-		ICMP_Addrmask_Ttl_Check(void):Xprobe_Module_Param_ICMP(XPROBE_MODULE_PARAM_RANGE) { return; }
-		//~ICMP_Addrmask_Ttl_Check(void) { return; }
+		ICMP_Addrmask_Ttl_Check(void):Xprobe_Module_Param(XPROBE_MODULE_PARAM_RANGE) { return; }
+		~ICMP_Addrmask_Ttl_Check(void) { return; }
 		int check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os);
 };
 
-class ICMP_Addrmask_Reply_Check:public Xprobe_Module_Param_ICMP {
+class ICMP_Addrmask_Reply_Check:public Xprobe_Module_Param {
 	public:
-		ICMP_Addrmask_Reply_Check(void):Xprobe_Module_Param_ICMP(XPROBE_MODULE_PARAM_BOOL) { return; }
-		//~ICMP_Addrmask_Reply_Check(void) { return; }
+		ICMP_Addrmask_Reply_Check(void):Xprobe_Module_Param(XPROBE_MODULE_PARAM_BOOL) { return; }
+		~ICMP_Addrmask_Reply_Check(void) { return; }
 		int check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os);
 };
 
