@@ -1,4 +1,4 @@
-/* $Id: icmp_echo_id.cc,v 1.16 2005/06/26 11:26:12 mederchik Exp $ */
+/* $Id: icmp_echo_id.cc,v 1.8 2003/04/04 04:01:59 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,18 +35,17 @@
 #include "target.h"
 #include "icmp_echo_id.h"
 
+#define TIMEOUT 5
 extern Interface *ui;
 
 /* initialization function */
 
-int icmp_echo_id_mod_init(Xprobe_Module_Hdlr *pt, char *nm) {
+int icmp_echo_id_mod_init(Xprobe_Module_Hdlr *pt) {
 
     ICMP_Echo_Id_Mod *module = new ICMP_Echo_Id_Mod;
 
-    module->set_name(nm);
     xprobe_mdebug(XPROBE_DEBUG_MODULES, "Initializing the ICMP ECHO ID module\n");
     pt->register_module(module);
-    pt->add_keyword(module->get_id(),"icmp_echo_reply");
     pt->add_keyword(module->get_id(),"icmp_echo_code");
     pt->add_keyword(module->get_id(),"icmp_echo_ip_id");
     pt->add_keyword(module->get_id(),"icmp_echo_tos_bits");
@@ -55,27 +55,25 @@ int icmp_echo_id_mod_init(Xprobe_Module_Hdlr *pt, char *nm) {
 return OK;
 }
 
-ICMP_Echo_Id_Mod::ICMP_Echo_Id_Mod(void): Xprobe_Module(XPROBE_MODULE_OSTEST, "fingerprint:icmp_echo","ICMP Echo request fingerprinting module") { 
+ICMP_Echo_Id_Mod::ICMP_Echo_Id_Mod(void): Xprobe_Module(XPROBE_MODULE_OSTEST, "ICMP echo") { 
     
     ICMP_Echo_Code_Chk *iecc = new ICMP_Echo_Code_Chk;
     ICMP_Echo_Id_Chk   *ieic = new ICMP_Echo_Id_Chk;
     ICMP_Echo_Tos_Chk  *ietc = new ICMP_Echo_Tos_Chk;
     ICMP_Echo_Df_Bit_Chk *iedbc = new ICMP_Echo_Df_Bit_Chk;
     ICMP_Echo_Reply_Ttl_Chk *iertc = new ICMP_Echo_Reply_Ttl_Chk;
-    ICMP_Echo_Reply_Check *ierc= new ICMP_Echo_Reply_Check;
 
-    kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_echo_reply", ierc));
-    kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_echo_code", iecc));
-    kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_echo_ip_id", ieic));
-    kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_echo_tos_bits", ietc));
-    kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_echo_df_bit", iedbc));
-    kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_echo_reply_ttl", iertc));
+    kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_echo_code", iecc));
+    kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_echo_ip_id", ieic));
+    kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_echo_tos_bits", ietc));
+    kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_echo_df_bit", iedbc));
+    kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_echo_reply_ttl", iertc));
     
     return;
 }
 
 ICMP_Echo_Id_Mod::~ICMP_Echo_Id_Mod(void) {
-    map <string, Xprobe_Module_Param_ICMP *>::iterator s_i;
+    map <string, Xprobe_Module_Param *>::iterator s_i;
 
 /* free check objects */
     for (s_i = kwd_chk.begin(); s_i != kwd_chk.end(); s_i++) 
@@ -133,18 +131,23 @@ void ICMP_Echo_Id_Mod::sig_ttl_insert(int os_id, int val) {
 
 
 int ICMP_Echo_Id_Mod::parse_keyword(int os_id, const char *kwd, const char *val)  {
-	map <string, Xprobe_Module_Param_ICMP *>::iterator s_i;
+         map <string, Xprobe_Module_Param *>::iterator s_i;
 
-    xprobe_debug(XPROBE_DEBUG_SIGNATURES, "Parsing for %i : %s  = %s\n",
+    xprobe_debug(XPROBE_DEBUG_MODULES, "Parsing for %i : %s  = %s\n",
                                                         os_id,  kwd, val);
-	if ((s_i=kwd_chk.find(kwd)) != kwd_chk.end()) {
+/* go through the list of keywords */
+    for (s_i = kwd_chk.begin(); s_i != kwd_chk.end(); s_i++) 
+        if ((*s_i).first == kwd) {
             return((*s_i).second->parse_param(os_id, val));
-	}
+        }
+       
     ui->msg("Ooops..none matched %s %s\n", kwd, val);   
     return FAIL;
 
 };
 
+
+
 int ICMP_Echo_Id_Mod::do_icmp_ping(Target *tg) {
 
     char buf[1024];
@@ -152,20 +155,20 @@ int ICMP_Echo_Id_Mod::do_icmp_ping(Target *tg) {
     int ret;
     int done;
     unsigned short int icmpp_id;
-    struct in_addr local, remote;
-    map <string, Xprobe_Module_Param_ICMP *>::iterator s_i;
+    struct in_addr local;
+    map <string, Xprobe_Module_Param *>::iterator s_i;
 
 /* our lamyer randomizer ;-p */
     srand(time(NULL));
     icmpp_id = rand();
     local = tg->get_interface_addr();
-	remote = tg->get_addr();
 
-    ICMP icmpp(inet_ntoa(remote));
+    ICMP icmpp(inet_ntoa(tg->get_addr()));
     ICMP sn(inet_ntoa(local));
     sn.init_device(tg->get_interface(), 0, 1500);
 
-    tv = tg->get_rtt();
+    tv.tv_sec = TIMEOUT;
+    tv.tv_usec = 0;
 
     icmpp.set_src(inet_ntoa(tg->get_interface_addr()));
 	// set ip id now, instead of letting os do that
@@ -187,94 +190,53 @@ int ICMP_Echo_Id_Mod::do_icmp_ping(Target *tg) {
     while (!done) {
         ret = sn.sniffpack(buf, sizeof(buf));
         /* packet response */
-//        if (ret > 0 && sn.get_src() != local.s_addr 
-        if (!sn.timeout() && sn.get_src() == remote.s_addr && 
-			sn.get_type() == ICMP_ECHOREPLY && sn.get_icmpId() == icmpp_id) {
-			done = 1;
-			xprobe_debug(XPROBE_DEBUG_MODULES, "[%s] Received reply.\n", get_name());
-		}
-//        if (ret < 1) done = 1; /* timeout */    
-        if (sn.timeout()) {
-			done = 1; /* timeout */    
-			xprobe_debug(XPROBE_DEBUG_MODULES, "[%s] Timed out, no reply received.\n", get_name());
-		}
+        if (ret > 0 && sn.get_src() != local.s_addr 
+            && sn.get_icmpId() == icmpp_id) done = 1;
+        if (ret < 1) done = 1; /* timeout */    
     }
     
-    if (! sn.timeout()) {
+    if (ret > 0) {
+        /*
+        do_code_check(sn.get_code());
+        do_ttl_check(sn.get_ttl());
+        */
         for (s_i = kwd_chk.begin(); s_i != kwd_chk.end(); s_i++) 
             ((*s_i).second->check_param(&sn, &icmpp, current_os));
         
-		if (tg->generate_sig())
-			generate_signature(tg, &sn, &icmpp);
         return OK;
     }
     return FAIL;
 
 }
 
-void ICMP_Echo_Id_Mod::generate_signature(Target *tg, ICMP *pack, ICMP *orig) {
-	string keyword, value;
-	unsigned int ttl;
-/*
-#       icmp_echo_code = [0, !0]
-#       icmp_echo_ip_id = [0, !0, SENT]
-#       icmp_echo_tos_bits = [0, !0]
-#       icmp_echo_df_bit = [0, 1]
-#       icmp_echo_reply_ttl = [>< decimal num]
-*/
-	if (!pack->timeout()) {
-		tg->signature("icmp_echo_reply", "y");
-		keyword = "icmp_echo_code";
-		if (pack->get_code() == 0)
-			value="0";
-		else 
-			value="!0";
-		tg->signature(keyword, value);
-		keyword= "icmp_echo_ip_id";
-		if (pack->get_id() == 0)
-			value = "0";
-		else if (pack->get_id() == orig->get_id())
-			value = "SENT";
-		else
-			value = "!0";
-		tg->signature(keyword, value);
-		keyword= "icmp_echo_tos_bits";
-		if (pack->get_tos() == 0)
-			value="0";
-		else 
-			value="!0";
-		tg->signature(keyword, value);
-		keyword = "icmp_echo_df_bit";
-		if (pack->get_fragoff() & IP_DF)
-			value = "1";
-		else 
-			value ="0";	
-		tg->signature(keyword, value);
-		keyword = "icmp_echo_reply_ttl";
-		ttl = pack->get_ttl() + tg->get_distance();
-		value = "<";
-		if (ttl <= 32)
-			value.append("32");
-		else if (ttl <= 60)
-			value.append("60");
-		else if (ttl <= 64)
-			value.append("64");
-		else if (ttl <= 128)
-			value.append("128");
-		else if (ttl <= 255)
-			value.append("255");
-		tg->signature(keyword, value);
-	} else {
-		tg->signature("# No ICMP Echo reply received", "");
-		tg->signature("icmp_echo_reply", "n");
-		tg->signature("icmp_echo_code", "");
-		tg->signature("icmp_echo_ip_id", "");
-		tg->signature("icmp_echo_tos_bits","");
-		tg->signature("icmp_echo_df_bit", "");
-		tg->signature("icmp_echo_reply_ttl", "");
-	}
-	
 
+void ICMP_Echo_Id_Mod::do_code_check(int code) {
+    map <int, int>::iterator sig_i;
+
+    for (sig_i = sig.begin(); sig_i != sig.end(); sig_i++) {
+    
+        if (code != 0 && (*sig_i).second == 1)
+            current_os->add_result(get_id(), (*sig_i).first, XPROBE_MATCH_YES);
+        else if (code == 0 && (*sig_i).second == 0)   
+            current_os->add_result(get_id(), (*sig_i).first, XPROBE_MATCH_YES);
+        else    
+            current_os->add_result(get_id(), (*sig_i).first, XPROBE_MATCH_NO);
+
+    }
+}
+
+void ICMP_Echo_Id_Mod::do_ttl_check(int ttl) {
+    map <int, int>::iterator sig_i;
+
+    for (sig_i = sig_ttl.begin(); sig_i != sig_ttl.end(); sig_i++) {
+		/* match TTLs in a fuzzy way */
+		if (ttl - TTL_DELTA < (*sig_i).second &&
+		    ttl + TTL_DELTA > (*sig_i).second)
+            current_os->add_result(get_id(), (*sig_i).first, XPROBE_MATCH_YES);
+        else    
+            current_os->add_result(get_id(), (*sig_i).first, XPROBE_MATCH_NO);
+
+    }
 }
 
 
@@ -299,7 +261,7 @@ int ICMP_Echo_Tos_Chk::check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os)
 
 int ICMP_Echo_Df_Bit_Chk::check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os) {
 
-   xprobe_debug(XPROBE_DEBUG_MODULES, "ICMP ip df %i\n",
+   xprobe_debug(XPROBE_DEBUG_MODULES, "ICMP ip df %i",
                         (ip_pkt->get_fragoff() & IP_DF) !=0?1:0);
    return (add_param(((ip_pkt->get_fragoff() & IP_DF) != 0), ((orig_pkt->get_fragoff() & IP_DF) != 0), os));
 }
@@ -310,13 +272,3 @@ int ICMP_Echo_Reply_Ttl_Chk::check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix
    return (add_param(ip_pkt->get_ttl(), orig_pkt->get_ttl(), os));
 }
 
-int ICMP_Echo_Reply_Check::check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os) {
-	int gotp=ip_pkt->timeout() ? 0 : 1;
-	// suspend warning
-	orig_pkt->timeout();
-	add_param(gotp, 0, os);
-	if (!gotp) {
-		gen_match(5, os);
-	}
-	return OK;
-}
