@@ -15,7 +15,7 @@ void icmp_port_unreach::build_DNS_reply (u_char *packet)
         u_char *localpacket = packet;
 
 		if ((hostip = gethostbyname(DNSMASQUERADE)) == NULL) {
-			ui->error("[-] icmp_port_unreach::build_DNS_reply(): gethostbyname() failed! Using static ip for www.securityfocus.com in UDP probe\n");
+			ui->error("icmp_port_unreach::build_DNS_reply(): gethostbyname() failed! Using static ip for www.securityfocus.com in UDP probe");
 			inet_aton("205.206.231.10", &secfocip);
 		} else
 			memcpy (&secfocip, hostip->h_addr, hostip->h_length);
