@@ -1,4 +1,4 @@
-/* $Id: util.h,v 1.8 2003/08/05 03:35:12 mederchik Exp $ */
+/* $Id: util.h,v 1.6 2003/03/19 14:24:26 mederchik Exp $ */
 /*
 ** Copyright (C) 2001, 2002 Meder Kydyraliev
 **
@@ -10,6 +10,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,6 +38,8 @@
 #define TRUE 1
 #define FALSE 0
 
+#define TIMEOUT 3
+
 #define DEFPORT 80
 
 #define TCPPACKETFLAGS TH_SYN
