@@ -1,4 +1,4 @@
-/* $Id: icmp_timestamp.cc,v 1.13 2005/06/26 11:26:13 mederchik Exp $ */
+/* $Id: icmp_timestamp.cc,v 1.5 2003/04/04 04:02:02 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,15 +34,15 @@
 #include "target.h"
 #include "icmp_timestamp.h"
 
+#define TIMEOUT 5
 extern Interface *ui;
 
 /* initialization function */
 
-int icmp_timestamp_mod_init(Xprobe_Module_Hdlr *pt, char *nm) {
+int icmp_timestamp_mod_init(Xprobe_Module_Hdlr *pt) {
 
     ICMP_Timestamp_Mod *module = new ICMP_Timestamp_Mod;
 
-    module->set_name(nm);
     xprobe_mdebug(XPROBE_DEBUG_MODULES, "Initializing the ICMP Timestamp module\n");
     pt->register_module(module);
     pt->add_keyword(module->get_id(),"icmp_timestamp_reply");
@@ -51,15 +52,14 @@ int icmp_timestamp_mod_init(Xprobe_Module_Hdlr *pt, char *nm) {
 return OK;
 }
 
-ICMP_Timestamp_Mod::ICMP_Timestamp_Mod(void):Xprobe_Module(XPROBE_MODULE_OSTEST, 
-		"fingerprint:icmp_tstamp", "ICMP Timestamp request fingerprinting module") {
+ICMP_Timestamp_Mod::ICMP_Timestamp_Mod(void):Xprobe_Module(XPROBE_MODULE_OSTEST, "ICMP Timestamp") {
 	ICMP_Timestamp_Reply_Check *timrep = new ICMP_Timestamp_Reply_Check;
 	ICMP_Timestamp_Ip_Id_Check *timid = new ICMP_Timestamp_Ip_Id_Check;
 	ICMP_Timestamp_Ttl_Check *timttl = new ICMP_Timestamp_Ttl_Check;
 
-	kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_timestamp_reply", timrep));
-	kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_timestamp_reply_ttl", timttl));
-	kwd_chk.insert(pair<string, Xprobe_Module_Param_ICMP *>("icmp_timestamp_reply_ip_id", timid));
+	kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_timestamp_reply", timrep));
+	kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_timestamp_reply_ttl", timttl));
+	kwd_chk.insert(pair<string, Xprobe_Module_Param *>("icmp_timestamp_reply_ip_id", timid));
 }
 
 ICMP_Timestamp_Mod::~ICMP_Timestamp_Mod(void) {
@@ -93,11 +93,10 @@ int ICMP_Timestamp_Mod::fini(void) {
 
 int ICMP_Timestamp_Mod::parse_keyword(int os_id, const char *kwd, const char *val) {
 
-	if ((s_i=kwd_chk.find(kwd)) != kwd_chk.end()) {
-		return s_i->second->parse_param(os_id, val);
-	}
-	ui->msg("Ooops..none matched %s %s\n", kwd, val);
-	return FAIL;
+	for (s_i=kwd_chk.begin(); s_i != kwd_chk.end(); s_i++)
+		if (s_i->first == kwd)
+			return s_i->second->parse_param(os_id, val);
+	return OK;
 }
 
 
@@ -109,18 +108,19 @@ int ICMP_Timestamp_Mod::do_icmp_query(Target *tg) {
     int ret;
     int done;
     unsigned short int icmpp_id;
-    struct in_addr local, remote;
+    struct in_addr local;
 
 /* our lamyer randomizer ;-p */
     srand(time(NULL));
     icmpp_id = rand();
     local = tg->get_interface_addr();
-	remote = tg->get_addr();
-    ICMP icmpp(inet_ntoa(remote));
+
+    ICMP icmpp(inet_ntoa(tg->get_addr()));
     ICMP sn(inet_ntoa(local));
     sn.init_device(tg->get_interface(), 0, 1500);
 
-    tv = tg->get_rtt();
+    tv.tv_sec = TIMEOUT;
+    tv.tv_usec = 0;
 
     icmpp.set_src(inet_ntoa(tg->get_interface_addr()));
     icmpp.set_icmpId(icmpp_id);
@@ -135,17 +135,10 @@ int ICMP_Timestamp_Mod::do_icmp_query(Target *tg) {
     while (!done) {
         ret = sn.sniffpack(buf, sizeof(buf));
         /* packet response */
-//        if (ret > 0 && sn.get_src() != local.s_addr 
-        if (!sn.timeout() && sn.get_src() == remote.s_addr 
-            && sn.get_type() == ICMP_TIMESTAMPREPLY && sn.get_icmpId() == icmpp_id) {
-			done = 1;
-			xprobe_debug(XPROBE_DEBUG_MODULES, "[%s] Received reply.\n", get_name());
-		}
+        if (ret > 0 && sn.get_src() != local.s_addr 
+            && sn.get_icmpId() == icmpp_id) done = 1;
      //   if (ret < 1) done = 1; /* timeout */    
-		if (sn.timeout()) {
-			done = 1;
-			xprobe_debug(XPROBE_DEBUG_MODULES, "[%s] Timed out, no reply received.\n", get_name());
-		}
+		if (sn.timeout()) done = 1;
     }
     
     /* do_response_check(ret);
@@ -154,53 +147,8 @@ int ICMP_Timestamp_Mod::do_icmp_query(Target *tg) {
 	*/
 	for (s_i = kwd_chk.begin(); s_i != kwd_chk.end(); s_i++) 
 		s_i->second->check_param(&sn, &icmpp, current_os);
-	if (tg->generate_sig())
-		generate_signature(tg, &sn, &icmpp);
     return OK;
 
-}
-
-void ICMP_Timestamp_Mod::generate_signature(Target *tg, ICMP *pack, ICMP *orig) {
-	string keyword, value;
-	unsigned int ttl;
-
-/* 
-#       icmp_timestamp_reply = [ y, n]
-#       icmp_timestamp_reply_ttl = [>< decimal num]
-#       icmp_timestamp_reply_ip_id = [0, !0, SENT]
-*/
-	if (!pack->timeout()) {
-		tg->signature("icmp_timestamp_reply", "y");
-		keyword = "icmp_timestamp_reply_ttl";
-		ttl = pack->get_ttl() + tg->get_distance();
-		value = "<";
-		if (ttl <= 32)
-			value.append("32");
-		else if (ttl <= 60)
-			value.append("60");
-		else if (ttl <= 64)
-			value.append("64");
-		else if (ttl <= 128)
-			value.append("128");
-		else if (ttl <= 255)
-			value.append("255");
-		tg->signature(keyword, value);	
-		keyword="icmp_timestamp_reply_ip_id";
-		if (pack->get_id() == 0)
-			value="0";
-		else if (pack->get_id() == orig->get_id())
-			value = "SENT";
-		else 
-			value = "!0";
-		tg->signature(keyword, value);
-	} else {
-		tg->signature("icmp_timestamp_reply", "n");
-		tg->signature("icmp_timestamp_reply_ttl", "<64");
-		tg->signature("icmp_timestamp_reply_ip_id", "!0");
-	}
-
-
-
 }
 
 int ICMP_Timestamp_Reply_Check::check_param(ICMP *ip_pkt, ICMP *orig_pkt, OS_Matrix *os) {
