@@ -1,4 +1,4 @@
-/* $Id: xprobe.cc,v 1.7 2004/09/05 07:18:00 mederchik Exp $ */
+/* $Id: xprobe.cc,v 1.3 2002/09/23 04:11:58 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,7 +29,6 @@
 #include "scan_engine.h"
 #include "interface_con.h"
 #include "os_matrix.h"
-#include "log.h"
 
 /* globals */
 
@@ -39,7 +39,6 @@ Xprobe_Module_Hdlr     *xmh;
 Interface       *ui;
 Scan_Engine     *se;
 OS_Name         *oses;
-XML_Log			*xml;
 
 int main(int argc, char *argv[]) {
 
@@ -50,8 +49,6 @@ int main(int argc, char *argv[]) {
     se      = new Scan_Engine;
     cfg     = new Config_Set;
     oses    = new OS_Name;
-	xml 	= new XML_Log;
-	time_t	start = time(NULL);
 
     ui->msg("%s\n",BANNER);
     copts->parse(argc, argv);
@@ -60,15 +57,10 @@ int main(int argc, char *argv[]) {
 	cfg->show_route(copts->show_route());
 	cfg->set_udp_ports(copts->get_udp_ports());
 	cfg->set_tcp_ports(copts->get_tcp_ports());
-	if (copts->do_xml())
-		if (xml->set_logfile(copts->get_logfile()))
-			exit(1);
     /* targets list */
     if (targets->init(copts->get_target()) == FAIL) {
         exit(1);
     }
-	xml->log(XPROBELOG_XP_SESS_START, "%v%b", VERSION, BANNER);
-	xml->log(XPROBELOG_MSG_RUN, "%c%a%d", argc, argv, start);
     
     /* config file */
     xprobe_debug(XPROBE_DEBUG_INIT, "[+] config file is: %s\n", copts->get_configfile());
@@ -99,7 +91,6 @@ int main(int argc, char *argv[]) {
 
     xmh->fini();
     ui->msg("[+] Execution completed.\n");
-	xml->log(XPROBELOG_XP_SESS_END, "FIN");
     delete oses;
     delete copts;
     delete targets;
@@ -107,6 +98,5 @@ int main(int argc, char *argv[]) {
     delete xmh;
     delete se;
     delete ui;
-	delete xml;
 
 }
