@@ -1,4 +1,4 @@
-/* $Id: xprobe_module_hdlr.h,v 1.7 2005/02/09 18:36:45 mederchik Exp $ */
+/* $Id: xprobe_module_hdlr.h,v 1.2 2002/10/21 03:59:42 mederchik Exp $ */
 /*
 ** Copyright (C) 2001 Fyodor Yarochkin <fygrave@tigerteam.net>,
 **                    Ofir Arkin       <ofir@sys-security.com>
@@ -8,6 +8,7 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
+** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,10 +27,8 @@
 #include "xprobe_module.h"
 #include "target.h"
 #include "os_matrix.h"
-/*
 #include <string>
 #include <map>
-*/
 
 using namespace std;
 
@@ -47,19 +46,9 @@ class Xprobe_Module_Hdlr {
         int exec(int, Target *, OS_Matrix *);
         int fini(void);
         
-		void display_mod_names(void);
         int register_module(Xprobe_Module *);
-        int add(int(*)(Xprobe_Module_Hdlr *, char *), char *);
+        int add(int(*)(Xprobe_Module_Hdlr *));
         void add_keyword(int, char *);
-		int get_module_count();
-		int modbyname(char *nm);	
-		bool mod_disabled_by_default(unsigned int ix) {
-			unsigned int disabled_mods[] = {0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0};
-			if (ix < sizeof(disabled_mods))
-				return (disabled_mods[ix] == 1);
-			else 
-				return false;
-		}
         Xprobe_Module *find_mod(string &);
         Xprobe_Module_Hdlr(void);
         ~Xprobe_Module_Hdlr(void);
